require './test/test_helper'

describe GitAgent::Notification do
  describe '#initialize' do
    it 'raises ArgumentError when :sender_username, :sender_password, or :recipient_username is not present' do
      GitAgent::Notification.config = { sender_username: '',  sender_password: '' }
      -> { GitAgent::Notification.new('sample_project', {}) }.must_raise ArgumentError

      GitAgent::Notification.config = { sender_password: '', recipient_username: '' }
      -> { GitAgent::Notification.new('sample_project', {}) }.must_raise ArgumentError

      GitAgent::Notification.config = { recipient_username: '', sender_username: '' }
      -> { GitAgent::Notification.new('sample_project', {}) }.must_raise ArgumentError
    end
  end

  describe '#send!' do
    before do
      Mail::TestMailer.deliveries.clear
      GitAgent::Notification.config = { sender_username: 'foo@gmail.com',
                                        sender_password: '123',
                                        recipient_username: 'bar@gmail.com' }
      Mail.defaults { delivery_method :test }
    end

    it 'sends an email to recipient' do
      notification = GitAgent::Notification.new('sample_project', { updated: ['refs/heads/master', 'HEAD'] })
      notification.send!

      Mail::TestMailer.deliveries.length.must_equal 1
    end
  end
end
